@@ -24,6 +24,18 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
     // Get the JWT credentials.
     let jwt = JWTCredentials::new(app_id, key.data).unwrap();
 
+    let http = reqwest::Client::builder().build()?;
+    let retry_policy =
+        reqwest_retry::policies::ExponentialBackoff::builder().build_with_max_retries(3);
+    let client = reqwest_middleware::ClientBuilder::new(http)
+        // Trace HTTP requests. See the tracing crate to make use of these traces.
+        .with(reqwest_tracing::TracingMiddleware)
+        // Retry failed requests.
+        .with(reqwest_retry::RetryTransientMiddleware::new_with_policy(
+            retry_policy,
+        ))
+        .build();
+
     // Create the HTTP cache.
     #[cfg(feature = "httpcache")]
     let mut dir = dirs::home_dir().expect("Expected a home dir");
@@ -39,7 +51,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         "https://api.github.com",
         concat!(env!("CARGO_PKG_NAME"), "/", env!("CARGO_PKG_VERSION")),
         Credentials::InstallationToken(token_generator),
-        reqwest::Client::builder().build().unwrap(),
+        client,
     );
 
     #[cfg(feature = "httpcache")]
@@ -47,7 +59,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
         "https://api.github.com",
         concat!(env!("CARGO_PKG_NAME"), "/", env!("CARGO_PKG_VERSION")),
         Credentials::InstallationToken(token_generator),
-        reqwest::Client::builder().build().unwrap(),
+        client,
         http_cache,
     );
 
