@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Reactions {
-    client: Client,
+    pub client: Client,
 }
 
 impl Reactions {
@@ -43,28 +43,24 @@ impl Reactions {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/teams/{}/discussions/{}/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&team_slug.to_string()),
             crate::progenitor_support::encode_path(&discussion_number.to_string()),
             crate::progenitor_support::encode_path(&comment_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -91,22 +87,18 @@ impl Reactions {
         comment_number: i64,
         content: crate::types::Content,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/teams/{}/discussions/{}/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&team_slug.to_string()),
             crate::progenitor_support::encode_path(&discussion_number.to_string()),
             crate::progenitor_support::encode_path(&comment_number.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -147,10 +139,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -222,27 +211,23 @@ impl Reactions {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/teams/{}/discussions/{}/reactions?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&team_slug.to_string()),
             crate::progenitor_support::encode_path(&discussion_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -268,21 +253,17 @@ impl Reactions {
         discussion_number: i64,
         content: crate::types::Content,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/teams/{}/discussions/{}/reactions?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&team_slug.to_string()),
             crate::progenitor_support::encode_path(&discussion_number.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -320,10 +301,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -414,27 +392,23 @@ impl Reactions {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&comment_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -458,21 +432,17 @@ impl Reactions {
         comment_id: i64,
         content: crate::types::Content,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&comment_id.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -508,10 +478,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -578,27 +545,23 @@ impl Reactions {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/issues/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&comment_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -622,21 +585,17 @@ impl Reactions {
         comment_id: i64,
         content: crate::types::Content,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/issues/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&comment_id.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -672,10 +631,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -742,27 +698,23 @@ impl Reactions {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/issues/{}/reactions?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&issue_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -786,21 +738,17 @@ impl Reactions {
         issue_number: i64,
         content: crate::types::Content,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/issues/{}/reactions?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&issue_number.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -836,10 +784,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -906,27 +851,23 @@ impl Reactions {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&comment_id.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -950,21 +891,17 @@ impl Reactions {
         comment_id: i64,
         content: crate::types::Content,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/repos/{}/{}/pulls/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&owner.to_string()),
             crate::progenitor_support::encode_path(&repo.to_string()),
             crate::progenitor_support::encode_path(&comment_id.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -1000,10 +937,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1073,10 +1007,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1109,27 +1040,23 @@ impl Reactions {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/teams/{}/discussions/{}/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&team_id.to_string()),
             crate::progenitor_support::encode_path(&discussion_number.to_string()),
             crate::progenitor_support::encode_path(&comment_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1155,21 +1082,17 @@ impl Reactions {
         comment_number: i64,
         content: crate::types::Content,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/teams/{}/discussions/{}/comments/{}/reactions?{}",
             crate::progenitor_support::encode_path(&team_id.to_string()),
             crate::progenitor_support::encode_path(&discussion_number.to_string()),
             crate::progenitor_support::encode_path(&comment_number.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -1207,10 +1130,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -1241,26 +1161,22 @@ impl Reactions {
         per_page: i64,
         page: i64,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
+        }
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/teams/{}/discussions/{}/reactions?{}",
             crate::progenitor_support::encode_path(&team_id.to_string()),
             crate::progenitor_support::encode_path(&discussion_number.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -1285,20 +1201,16 @@ impl Reactions {
         discussion_number: i64,
         content: crate::types::Content,
     ) -> Result<Vec<crate::types::Reaction>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("content={}", content));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !content.to_string().is_empty() {
+            query_args.push(("content".to_string(), content.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/teams/{}/discussions/{}/reactions?{}",
             crate::progenitor_support::encode_path(&team_id.to_string()),
             crate::progenitor_support::encode_path(&discussion_number.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -1333,10 +1245,7 @@ impl Reactions {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
